==> oauth_server_sso-7.x-1.1.tar.gz: oauth_server_sso/includes/Utilities.php <==
<?php

class Utilities
{
    public static function isCurlInstalled()
    {
        if (in_array('curl', get_loaded_extensions()))
        {
            return 1;
        }
        else
        {
            return 0;
        }
    }

    public static function getdbconnection(){
      $connection = Database::getConnection();
      return $connection;
    }

    public static function advertiseClient(array &$form, $form_state)
    {
        $form['markup_oauth_server_attr_header_top_support'] = array('#markup' => '</div><div class="mo_saml_table_layout_support_1 mo_oauth_container" id="ma_saml_support_query">',);
        global $base_url;
        $module_path = drupal_get_path('module', 'oauth_server_sso');
        $form['miniorange_oauth_client_setup_guide_link'] = array(
            '#markup' => '<div class="mo_saml_table_layout mo_saml_container_2" id="mo_oauth_guide_vt">',
        );

        $form['miniorange_oauth_client_guide_link1'] = array(
            '#markup' => '<div style="font-size: 15px;"><i>Looking for a Drupal OAuth Client module? Now create your own Drupal site as an OAuth Client.</i></div></br>',
        );
        $form['miniorange_oauth_server_guide_table_list'] = array(
            '#markup' => '<div class="table-responsive mo_guide_text-center" style="font-family: sans-serif;font-size: 15px;">
                <table class="" style="border: none !important;max-width: 100%;border-collapse: collapse;">
                    <thead>
                        <tr><th class="mo_guide_text-center" style="border: none;"><img src="'.$base_url.'/'. $module_path . '/includes/images/miniorange.png" alt="Simply Easy Learning" height = 80px width = 80px ></th><th class="mo_guide_text-center" style = "border: none;"><b>OAuth Single Sign On – SSO (OAuth Client)</b></th></tr>
                    </thead>
                </table>
                <div>
                    <p>OAuth Client module allows Single Sign-On by creating your Drupal site as an OAUth Client. It allows you to login in Drupal with any OAuth Server / Provider of your choice using OAuth Protocol</p>
                    <br>
                </div>
                <table>
                    <tr>
                    <a class="btn btn-get-module btn-large" href="https://www.drupal.org/project/miniorange_oauth_client" target ="_blank">
                        Download module
                    </a>
                    <a class="btn btn-know-more btn-large" href="https://plugins.miniorange.com/drupal-oauth-client" target ="_blank">
                        Know more
                    </a>
                    </tr>
                </table>
            </div>',
        );
    }

    public static function AddsupportTab(&$form, $form_state)
    {
        $form['markup_idp_attr_header_top_support'] = array('#markup' => '</div><div class="mo_saml_table_layout_support_1 mo_oauth_container" id="ma_saml_support_query">',);

        $form['markup_support_1'] = array(
            '#markup' => '<h3><b>Feature Request/Contact Us:</b></h3><div>Need any help? We can help you with configuring your OAuth Client. Just send us a query and we will get back to you soon.<br /></div><br>',
        );

        $form['oauth_server_sso_email_address'] = array(
            '#type' => 'textfield',
            '#id' => 'mo_textfield',
            '#attributes' => array('style'=>'width:100%','placeholder' => 'Enter your email'),
        );

        $form['oauth_server_sso_phone_number'] = array(
            '#type' => 'textfield',
            '#id' => 'mo_textfield',
            '#attributes' => array('style'=>'width:100%','placeholder' => 'Enter your phone number'),
        );

        $form['oauth_server_sso_support_query'] = array(
            '#type' => 'textarea',
            '#cols' => '10',
            '#rows' => '5',
            '#attributes' => array('style'=>'width:100%','placeholder' => 'Write your query here'),
        );

        $form['oauth_server_sso_support_submits'] = array(
            '#type' => 'submit',
            '#value' => t('Submit Query'),
            '#id' => 'button_config_center',
            '#submit' => array('send_support_query'),
        );

        $form['oauth_server_sso_support_note'] = array(
            '#markup' => '<div><br/>If you want custom features in the plugin, just drop an email to <a href="mailto:info@xecurify.com">info@xecurify.com</a></div>'
        );
    }
    public static function send_query($email, $phone, $query)
    {
        if(empty($email)||empty($query)){
            drupal_set_message(t('The <b><u>Email</u></b> and <b><u>Query</u></b> fields are mandatory.'), 'error');
            return;
        } elseif(!valid_email_address($email)) {
            drupal_set_message(t('The email address <b><i>' . $email . '</i></b> is not valid.'), 'error');
            return;
        }
        $support = new MiniorangeOAuthServerSupport($email, $phone, $query);
        $support_response = $support->sendSupportQuery();
        if($support_response) {
            drupal_set_message(t('Support query successfully sent.'));
        }
        else {
            drupal_set_message(t('Error sending support query. Please check your internet connection.'), 'error');
        }
    }

}

==> oauth_server_sso-7.x-1.2.tar.gz: oauth_server_sso/includes/Utilities.php <==
<?php

class Utilities
{
    public static function isCurlInstalled()
    {
        if (in_array('curl', get_loaded_extensions()))
        {
            return 1;
        }
        else
        {
            return 0;
        }
    }

    public static function getdbconnection(){
      $connection = Database::getConnection();
      return $connection;
    }

    public static function advertiseClient(array &$form, $form_state)
    {
        $form['markup_oauth_server_attr_header_top_support'] = array('#markup' => '</div><div class="mo_saml_table_layout_support_1 mo_oauth_container" id="ma_saml_support_query">',);
        global $base_url;
        $module_path = drupal_get_path('module', 'oauth_server_sso');
        $form['miniorange_oauth_client_setup_guide_link'] = array(
            '#markup' => '<div class="mo_saml_table_layout mo_saml_container_2" id="mo_oauth_guide_vt">',
        );

        $form['miniorange_oauth_client_guide_link1'] = array(
            '#markup' => '<div style="font-size: 15px;"><i>Looking for a Drupal OAuth Client module? Now create your own Drupal site as an OAuth Client.</i></div></br>',
        );
        $form['miniorange_oauth_server_guide_table_list'] = array(
            '#markup' => '<div class="table-responsive mo_guide_text-center" style="font-family: sans-serif;font-size: 15px;">
                <table class="" style="border: none !important;max-width: 100%;border-collapse: collapse;">
                    <thead>
                        <tr><th class="mo_guide_text-center" style="border: none;"><img src="'.$base_url.'/'. $module_path . '/includes/images/miniorange.png" alt="Simply Easy Learning" height = 80px width = 80px ></th><th class="mo_guide_text-center" style = "border: none;"><b>OAuth Single Sign On – SSO (OAuth Client)</b></th></tr>
                    </thead>
                </table>
                <div>
                    <p>OAuth Client module allows Single Sign-On by creating your Drupal site as an OAuth Client. It allows you to login in Drupal with any OAuth Server / Provider of your choice using OAuth Protocol</p>
                    <br>
                </div>
                <table>
                    <tr>
                    <a class="btn btn-get-module btn-large" href="https://www.drupal.org/project/miniorange_oauth_client" target ="_blank">
                        Download module
                    </a>
                    <a class="btn btn-know-more btn-large" href="https://plugins.miniorange.com/drupal-oauth-client" target ="_blank">
                        Know more
                    </a>
                    </tr>
                </table>
            </div>',
        );
    }

    public static function AddsupportTab(&$form, $form_state)
    {
        $form['markup_idp_attr_header_top_support'] = array('#markup' => '</div><div class="mo_saml_table_layout_support_1 mo_oauth_container" id="ma_saml_support_query">',);

        $form['markup_support_1'] = array(
            '#markup' => '<h3><b>Feature Request/Contact Us:</b></h3><div>Need any help? We can help you with configuring your OAuth Client. Just send us a query and we will get back to you soon.<br /></div><br>',
        );

        $form['oauth_server_sso_email_address'] = array(
            '#type' => 'textfield',
            '#id' => 'mo_textfield',
            '#attributes' => array('style'=>'width:100%','placeholder' => 'Enter your email'),
        );

        $form['oauth_server_sso_phone_number'] = array(
            '#type' => 'textfield',
            '#id' => 'mo_textfield',
            '#attributes' => array('style'=>'width:100%','placeholder' => 'Enter your phone number'),
        );

        $form['oauth_server_sso_support_query'] = array(
            '#type' => 'textarea',
            '#cols' => '10',
            '#rows' => '5',
            '#attributes' => array('style'=>'width:100%','placeholder' => 'Write your query here'),
        );

        $form['oauth_server_sso_support_submits'] = array(
            '#type' => 'submit',
            '#value' => t('Submit Query'),
            '#id' => 'button_config_center',
            '#submit' => array('send_support_query'),
        );

        $form['oauth_server_sso_support_note'] = array(
            '#markup' => '<div><br/>If you want custom features in the plugin, just drop an email to <a target="_blank" href="mailto:drupalsupport@xecurify.com">drupalsupport@xecurify.com</a></div>'
        );
    }
    public static function send_query($email, $phone, $query)
    {
        if(empty($email)||empty($query)){
            drupal_set_message(t('The <b><u>Email</u></b> and <b><u>Query</u></b> fields are mandatory.'), 'error');
            return;
        } elseif(!valid_email_address($email)) {
            drupal_set_message(t('The email address <b><i>' . $email . '</i></b> is not valid.'), 'error');
            return;
        }
        $support = new MiniorangeOAuthServerSupport($email, $phone, $query);
        $support_response = $support->sendSupportQuery();
        if($support_response) {
            drupal_set_message(t('Support query successfully sent.'));
        }
        else {
            drupal_set_message(t('Error sending support query. Please reach out to <a target="_blank" href="mailto:drupalsupport@xecurify.com">drupalsupport@xecurify.com</a>'), 'error');
        }
    }

}
